%bcond_without static_libs # don't build static libraries

Summary:        Library providing binary-decimal and decimal-binary routines for IEEE doubles
Name:           double-conversion
Version:        2.0.1
Release:        8%{?dist}
License:        BSD
Group:          Development/Libraries
Source0:        https://github.com/floitsch/double-conversion/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# Upstream patch to support SOVERSION
Patch0:         double-conversion-soversion.patch
# Use install paths in installed cmake files
# https://github.com/floitsch/double-conversion/pull/9
Patch1:         double-conversion-cmake.patch
URL:            https://github.com/floitsch/double-conversion
BuildRequires:  cmake

%description
Provides binary-decimal and decimal-binary routines for IEEE doubles.
The library consists of efficient conversion routines that have been
extracted from the V8 JavaScript engine. The code has been re-factored
and improved so that it can be used more easily in other projects.

%package devel
Summary:    Library providing binary-decimal and decimal-binary routines for IEEE doubles
Group:      Development/Libraries
Requires:   %{name}%{?_isa} = %{version}-%{release}

%description devel
Contains header files for developing applications that use the %{name}
library.

There is extensive documentation in src/double-conversion.h. Other
examples can be found in test/cctest/test-conversions.cc.

%package static
Summary:    Library providing binary-decimal and decimal-binary routines for IEEE doubles
Group:      Development/Libraries
Requires:   %{name}-devel%{?_isa} = %{version}-%{release}

%description static
Static %{name} library.

%prep
%setup -q
%patch0 -p1 -b .soversion
%patch1 -p1 -b .cmake
# Fix up install locations
# https://github.com/floitsch/double-conversion/issues/8
sed -i -e s,lib/CMake,%{_lib}/cmake, CMakeLists.txt
sed -i -e s,/lib,/%{_lib}, src/CMakeLists.txt

%build
mkdir -p build-shared
pushd build-shared
  %cmake -DBUILD_TESTING=ON ..
  make %{_smp_mflags}
popd

%if %{with static_libs}
mkdir  -p build-static
pushd build-static
  CXXFLAGS="%{optflags} -fPIC" %cmake -DBUILD_SHARED_LIBS=NO ..
  make %{_smp_mflags}
popd
%endif

%install
%if %{with static_libs}
pushd build-static
  make install DESTDIR=%{buildroot}
popd
%endif

pushd build-shared
  make install DESTDIR=%{buildroot}
popd

%check
pushd build-shared
  ctest -V
popd

%post -p /sbin/ldconfig
%postun  -p /sbin/ldconfig

%files
%doc LICENSE README AUTHORS Changelog
%{_libdir}/libdouble-conversion.so.1*

%files devel
%{_libdir}/libdouble-conversion.so
%{_libdir}/cmake/%{name}
%{_includedir}/%{name}

%if %{with static_libs}
%files static
%{_libdir}/libdouble-conversion.a
%endif

%changelog
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Mar 13 2015 Orion Poplawski <orion@cora.nwra.com> - 2.0.1-5
- Use github source

* Wed Mar 11 2015 Orion Poplawski <orion@cora.nwra.com> - 2.0.1-4
- Build with cmake

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Feb 8 2014 Milan Bouchet-Valat <nalimilan@club.fr> - 2.0.1-1
- New upstream version.
- Drop no longer needed custom SConstruct file and use new upstream SONAME.

* Tue Dec 17 2013 Milan Bouchet-Valat <nalimilan@club.fr> - 2.0.0-4
- Drop libstdc++-devel from BuildRequires.
- Move %%check after %%install.

* Sat Dec 14 2013 Milan Bouchet-Valat <nalimilan@club.fr> - 2.0.0-3
- Remove gcc-c++ from BuildRequires as it is an exception.
- Fix command in %%check and pass CXXFLAGS to scons.
- Use %%global instead of %%define.

* Thu Dec 12 2013 Milan Bouchet-Valat <nalimilan@club.fr> - 2.0.0-2
- Fix building when "--without static_libs" is passed.
- Remove %%ghost with libdouble-conversion.so.2.
- Drop BuildRoot.
- Use rm instead of %%{__rm} for consistency
- Use %%{?dist} in Release.

* Wed Dec 11 2013 Milan Bouchet-Valat <nalimilan@club.fr> - 2.0.0-1
- Initial Fedora package based on a PLD Linux RPM by Elan Ruusamäe <glen@delfi.ee>:
  http://git.pld-linux.org/gitweb.cgi?p=packages/double-conversion.git
